package com.inspect.alarminfo.mapper;

import com.inspect.alarminfo.domain.AlarmInfo;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface AlarmInfoMapper {
    AlarmInfo selectAlarmInfoByLineId(Long lineId);

    List<AlarmInfo> selectAlarmInfoList(AlarmInfo alarmInfo);

    int insertAlarmInfo(AlarmInfo alarmInfo);

    int updateAlarmInfo(AlarmInfo alarmInfo);

    int deleteAlarmInfoByLineId(Long lineId);

    int deleteAlarmInfoByLineIds(Long[] lineIds);
}
